@@ -1,8 +1,7 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::bool;
-our $VERSION = '0.007';
-
+our $VERSION = '0.100110';
 use base 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //bool type
 
@@ -15,6 +14,8 @@ sub check {
     and (
       eval { $value->isa('JSON::XS::Boolean') }
       or
+      eval { $value->isa('JSON::PP::Boolean') }
+      or
       eval { $value->isa('boolean') }
     )
   );
@@ -25,7 +26,6 @@ sub subname   { 'bool' }
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -34,7 +34,7 @@ Data::Rx::CoreType::bool - the Rx //bool type
 
 =head1 VERSION
 
-version 0.007
+version 0.100110
 
 =head1 AUTHOR
 
@@ -42,11 +42,10 @@ version 0.007
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
