@@ -1,16 +1,15 @@
 use strict;
 use warnings;
 package Test::RxSpec;
-our $VERSION = '0.007';
-
+our $VERSION = '0.100110';
 
 use autodie;
 use Data::Rx;
 use File::Find::Rule;
-use JSON::XS ();
+use JSON 2 ();
 use Test::More;
 
-my $JSON = JSON::XS->new;
+my $JSON = JSON->new;
 sub decode_json { $JSON->decode($_[0]) }
 
 sub slurp_json {
